---
title: repo-info
eleventyNavigation:
  key: repo-info
  parent: 🎬 Actions
---

{% include snippet/command-line/sample.md %}

```
{% include borgmatic/command-line/repo-info.txt %}
```


## Related documentation

 * [How to inspect your backups](https://torsion.org/borgmatic/how-to/inspect-your-backups/)
